{ stylix, ... }:
let
  wallpapers =
    builtins.mapAttrs
      (
        name: value:
        {
          lib,
          pkgs,
          ...
        }:
        {
          stylix.image = pkgs.fetchurl {
            url = value.url;
            hash = value.hash or lib.fakeHash;
          };
        }
      )
      {
        sekiro.url = "https://w.wallhaven.cc/full/vg/wallhaven-vgor6p.jpg";
        sekiro.hash = "sha256-pcNIr1yON9SsOhUAr//GGbijZayksBTYBu7l+/1+He8=";
      };
in
{
  personal.modules = [
    stylix.nixosModules.stylix
    (
      {
        pkgs,
        config,
        ...
      }:
      {
        stylix.enable = true;

        stylix.polarity = "dark";

        stylix.fonts.monospace.package = pkgs.nerdfonts;
        stylix.fonts.monospace.name = "FiraCode Nerd Font";

        stylix.fonts.sansSerif.package = pkgs.nerdfonts;
        stylix.fonts.sansSerif.name = "Ubuntu Nerd Font";
        stylix.fonts.serif = config.stylix.fonts.sansSerif;

        stylix.fonts.sizes.applications = 10;
        stylix.fonts.sizes.desktop = 12;

        stylix.cursor.package = pkgs.afterglow-cursors-recolored;
        stylix.cursor.name = "Afterglow-Recolored-Dracula-Green";
        stylix.cursor.size = 24;

        stylix.opacity.terminal = 0.9;
      }
    )
  ];
  capsaicin.modules = [
    wallpapers.sekiro
  ];
  menthol.modules = [
    wallpapers.sekiro
  ];
  personal.home_modules = [
    {
      stylix.targets.vscode.enable = false;
    }
    (
      {
        lib,
        pkgs,
        config,
        ...
      }:
      {
        systemd-fuckery.auto-restart = [ "swaybg" ];
        systemd.user.services."swaybg" = {
          Unit = {
            Description = "wallpapers! brought to you by stylix! :3";
            PartOf = [ "graphical-session.target" ];
          };
          Install.WantedBy = [ "graphical-session.target" ];
          Service = {
            ExecStart = "${lib.getExe pkgs.swaybg} -i ${config.stylix.image}";
            Restart = "on-failure";
          };
        };
      }
    )
  ];
}
